@@ -244,7 +244,7 @@ def is_five_band(frequency: int) -> bool:
 
 def is_six_band(frequency: int) -> bool:
     """determines if a channel frequency is in the 6.0-7.125 GHz ISM band"""
-    if __get_digit(frequency, __num_digits(frequency) - 1) == 6:
+    if frequency > 5900 and frequency < 7125:
         return True
     else:
         return False
